@@ -1,6 +1,5 @@
 # Gearman Perl front end
-# Copyright (C) 2013 Data Differential, http://datadifferential.com/
-# Copyright (C) 2009-2010 Dennis Schoen
+# Copyright (C) 2009 Dennis Schoen
 # All rights reserved.
 #
 # This library is free software; you can redistribute it and/or modify
@@ -9,16 +8,10 @@
 
 package Gearman::XS::Client;
 
-use strict;
-use warnings;
-
-our $VERSION= '0.15';
+our $VERSION = '0.2';
 
 use Gearman::XS;
 
-1;
-__END__
-
 =head1 NAME
 
 Gearman::XS::Client - Perl client for gearman using libgearman
@@ -31,23 +24,20 @@ Gearman::XS::Client - Perl client for gearman using libgearman
   $client = new Gearman::XS::Client;
 
   $ret = $client->add_server($host, $port);
-  if ($ret != GEARMAN_SUCCESS)
-  {
+  if ($ret != GEARMAN_SUCCESS) {
     printf(STDERR "%s\n", $client->error());
     exit(1);
   }
 
   # single client interface
   ($ret, $result) = $client->do("reverse", 'teststring');
-  if ($ret == GEARMAN_SUCCESS)
-  {
+  if ($ret == GEARMAN_SUCCESS) {
     printf("Result=%s\n", $result);
   }
 
   # background client interface
   ($ret, $job_handle) = $client->do_background('reverse', 'teststring);
-  if ($ret != GEARMAN_SUCCESS)
-  {
+  if ($ret != GEARMAN_SUCCESS) {
     printf(STDERR "%s\n", $client->error());
     exit(1);
   }
@@ -83,35 +73,6 @@ Add a list of job servers to a client. The format for the server list is:
 SERVER[:PORT][,SERVER[:PORT]]... No socket I/O happens here, it is just added
 to a list. Returns a standard gearman return value.
 
-=head2 $client->remove_servers()
-
-Remove all servers currently associated with the client.
-
-=head2 $client->options()
-
-Get options for a client.
-
-=head2 $client->set_options($options)
-
-Set options for a client.
-
-=head2 $client->add_options($options)
-
-Add options for a client.
-
-=head2 $client->remove_options($options)
-
-Remove options for a client.
-
-=head2 $client->timeout()
-
-Get current socket I/O activity timeout value. Returns Timeout in milliseconds
-to wait for I/O activity.
-
-=head2 $client->set_timeout($timeout)
-
-Set socket I/O activity timeout for connections in milliseconds.
-
 =head2 $client->echo($data)
 
 Send data to all job servers to see if they echo it back. This is a test
@@ -143,7 +104,7 @@ standard gearman return value, the second is the job handle.
 Run a high priority task in the background and return a list with two entries:
 the first is a standard gearman return value, the second is the job handle.
 
-=head2 $client->do_low_background($function_name, $workload)
+=head2 $client->do_log_background($function_name, $workload)
 
 Run a low priority task in the background and return a list with two entries:
 the first is a standard gearman return value, the second is the job handle.
@@ -184,12 +145,6 @@ Add a low priority background task to be run in parallel and return a list
 with two entries: the first is a standard gearman return value, the second is a
 Gearman::XS::Task object.
 
-=head2 $client->add_task_status($job_handle)
-
-Add task to get the status for a background task in parallel and return a list
-with two entries: the first is a standard gearman return value, the second is a
-Gearman::XS::Task object.
-
 =head2 $client->run_tasks()
 
 Run tasks that have been added in parallel. Returns a standard gearman return
@@ -215,11 +170,6 @@ Set callback function when a task has failed. No return value.
 
 Set callback function when there is a status packet for a task. No return value.
 
-=head2 $client->set_warning_fn($subref)
-
-Set callback function when there is a warning packet for a task.
-No return value.
-
 =head2 $client->error()
 
 Return an error string for the last error encountered.
@@ -235,14 +185,6 @@ Get the status for a background job. Returns a list with 5 entries: standard
 gearman return value, boolean indicating the know status, boolean indicating
 the running status, and the precent complete numerator and denominator.
 
-=head2 $client->wait()
-
-When in non-blocking I/O mode, wait for activity from one of the servers.
-
-=head2 $client->clear_fn()
-
-Clear all task callback functions.
-
 =head1 CALLBACKS
 
 Please make sure that callback functions always explicitly return a valid
@@ -255,8 +197,7 @@ Any in libgearman plus many others of my own.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2013 Data Differential, ala Brian Aker, http://datadifferential.com/
-Copyright (C) 2009-2010 Dennis Schoen
+Copyright (C) 2009 Dennis Schoen
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.9 or,
@@ -266,13 +207,10 @@ at your option, any later version of Perl 5 you may have available.
 
 This is free software. IT COMES WITHOUT WARRANTY OF ANY KIND.
 
-=head1 LICENSE
+=head1 AUTHORS
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 AUTHOR
-
-Brian Aker <brian@tangent.org>
+Dennis Schoen <dennis@blogma.de>
 
 =cut
+
+1;
\ No newline at end of file
