@@ -1,6 +1,5 @@
 # Gearman Perl front end
-# Copyright (C) 2013 Data Differential, http://datadifferential.com/
-# Copyright (C) 2009-2010 Dennis Schoen
+# Copyright (C) 2009 Dennis Schoen
 # All rights reserved.
 #
 # This library is free software; you can redistribute it and/or modify
@@ -9,16 +8,10 @@
 
 package Gearman::XS::Job;
 
-use strict;
-use warnings;
-
-our $VERSION= '0.15';
+our $VERSION = '0.2';
 
 use Gearman::XS;
 
-1;
-__END__
-
 =head1 NAME
 
 Gearman::XS::Job - Perl job for gearman using libgearman
@@ -38,6 +31,11 @@ Get the workload for a job.
 
 Get job handle.
 
+=head2 $job->status($numerator, $denominator)
+
+Send status information for a running job. Returns a standard gearman return
+value.
+
 =head2 $job->function_name()
 
 Get the function name associated with a job.
@@ -46,36 +44,21 @@ Get the function name associated with a job.
 
 Get the unique ID associated with a job.
 
-=head2 $job->send_status($numerator, $denominator)
-
-Send status information for a running job. Returns a standard gearman return
-value.
-
-=head2 $job->send_data($data)
+=head2 $job->data($data)
 
 Send data for a running job. Returns a standard gearman return value.
 
-=head2 $job->send_fail()
+=head2 $job->fail()
 
 Send fail status for a job. Returns a standard gearman return value.
 
-=head2 $job->send_complete($result)
-
-Send result and complete status for a job. Returns a standard gearman return
-value.
-
-=head2 $job->send_warning($warning)
-
-Send warning for a running job. Returns a standard gearman return value.
-
 =head1 BUGS
 
 Any in libgearman plus many others of my own.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2013 Data Differential, ala Brian Aker, http://datadifferential.com/
-Copyright (C) 2009-2010 Dennis Schoen
+Copyright (C) 2009 Dennis Schoen
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.9 or,
@@ -85,13 +68,10 @@ at your option, any later version of Perl 5 you may have available.
 
 This is free software. IT COMES WITHOUT WARRANTY OF ANY KIND.
 
-=head1 LICENSE
+=head1 AUTHORS
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 AUTHOR
-
-Brian Aker <brian@tangent.org>
+Dennis Schoen <dennis@blogma.de>
 
 =cut
+
+1;
\ No newline at end of file
