@@ -1,6 +1,5 @@
 # Gearman Perl front end
-# Copyright (C) 2013 Data Differential, http://datadifferential.com/
-# Copyright (C) 2009-2010 Dennis Schoen
+# Copyright (C) 2009 Dennis Schoen
 # All rights reserved.
 #
 # This library is free software; you can redistribute it and/or modify
@@ -9,16 +8,10 @@
 
 package Gearman::XS::Task;
 
-use strict;
-use warnings;
-
-our $VERSION= '0.15';
+our $VERSION = '0.1';
 
 use Gearman::XS;
 
-1;
-__END__
-
 =head1 NAME
 
 Gearman::XS::Task - Perl task for gearman using libgearman
@@ -42,7 +35,7 @@ Get data being returned for a task.
 
 Get data size being returned for a task.
 
-=head2 $task->function_name()
+=head2 $task->function()
 
 Get function name associated with a task.
 
@@ -54,28 +47,17 @@ Get the numerator of percentage complete for a task.
 
 Get the denominator of percentage complete for a task.
 
-=head2 $task->unique()
+=head2 $task->uuid()
 
 Get unique identifier for a task.
 
-=head2 $task->is_known()
-
-Get status on whether a task is known or not. Returns 1 if known, empty string
-if not.
-
-=head2 $task->is_running()
-
-Get status on whether a task is running or not. Returns 1 if running, empty
-string if not.
-
 =head1 BUGS
 
 Any in libgearman plus many others of my own.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2013 Data Differential, ala Brian Aker, http://datadifferential.com/
-Copyright (C) 2009-2010 Dennis Schoen
+Copyright (C) 2009 Dennis Schoen
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.9 or,
@@ -85,13 +67,10 @@ at your option, any later version of Perl 5 you may have available.
 
 This is free software. IT COMES WITHOUT WARRANTY OF ANY KIND.
 
-=head1 LICENSE
+=head1 AUTHORS
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 AUTHOR
-
-Brian Aker <brian@tangent.org>
+Dennis Schoen <dennis@blogma.de>
 
 =cut
+
+1;
\ No newline at end of file
