@@ -1,6 +1,5 @@
 # Gearman Perl front end
-# Copyright (C) 2013 Data Differential, http://datadifferential.com/
-# Copyright (C) 2009-2010 Dennis Schoen
+# Copyright (C) 2009 Dennis Schoen
 # All rights reserved.
 #
 # This library is free software; you can redistribute it and/or modify
@@ -9,16 +8,10 @@
 
 package Gearman::XS::Worker;
 
-use strict;
-use warnings;
-
-our $VERSION= '0.15';
+our $VERSION = '0.2';
 
 use Gearman::XS;
 
-1;
-__END__
-
 =head1 NAME
 
 Gearman::XS::Worker - Perl worker for gearman using libgearman
@@ -31,23 +24,19 @@ Gearman::XS::Worker - Perl worker for gearman using libgearman
   $worker = new Gearman::XS::Worker;
 
   $ret = $worker->add_server($host, $port);
-  if ($ret != GEARMAN_SUCCESS)
-  {
+  if ($ret != GEARMAN_SUCCESS) {
     printf(STDERR "%s\n", $worker->error());
     exit(1);
   }
 
   $ret = $worker->add_function("reverse", 0, \&reverse, $options);
-  if ($ret != GEARMAN_SUCCESS)
-  {
+  if ($ret != GEARMAN_SUCCESS) {
     printf(STDERR "%s\n", $worker->error());
   }
 
-  while (1)
-  {
+  while (1) {
     my $ret = $worker->work();
-    if ($ret != GEARMAN_SUCCESS)
-    {
+    if ($ret != GEARMAN_SUCCESS) {
       printf(STDERR "%s\n", $worker->error());
     }
   }
@@ -89,10 +78,6 @@ Add a list of job servers to a worker. The format for the server list is:
 SERVER[:PORT][,SERVER[:PORT]]... No socket I/O happens here, it is just added
 to a list. Returns a standard gearman return value.
 
-=head2 $worker->remove_servers()
-
-Remove all servers currently associated with the worker.
-
 =head2 $worker->echo($data)
 
 Send data to all job servers to see if they echo it back. This is a test
@@ -109,66 +94,13 @@ return value.
 Wait for a job and call the appropriate callback function when it gets one.
 Returns a standard gearman return value.
 
-=head2 $worker->grab_job()
-
-Get a job from one of the job servers. Returns a standard gearman return value.
-
 =head2 $worker->error()
 
 Return an error string for the last error encountered.
 
-=head2 $worker->options()
+=head2 $worker->set_options($options, $data)
 
-Get options for a worker.
-
-=head2 $worker->set_options($options)
-
-Set options for a worker.
-
-=head2 $worker->add_options($options)
-
-Add options for a worker.
-
-=head2 $worker->remove_options($options)
-
-Remove options for a worker.
-
-=head2 $worker->timeout()
-
-Get current socket I/O activity timeout value. Returns Timeout in milliseconds
-to wait for I/O activity.
-
-=head2 $worker->set_timeout($timeout)
-
-Set socket I/O activity timeout for connections in milliseconds.
-
-=head2 $worker->register($function_name, $timeout)
-
-Register function with job servers with an optional timeout. The timeout
-specifies how many seconds the server will wait before marking a job as failed.
-Returns a standard gearman return value.
-
-=head2 $worker->unregister($function_name)
-
-Unregister function with job servers. Returns a standard gearman return value.
-
-=head2 $worker->unregister_all()
-
-Unregister all functions with job servers. Returns a standard gearman return
-value.
-
-=head2 $worker->function_exist($function_name)
-
-See if a function exists in the server. Returns 1 if the function exists,
-empty string if not.
-
-=head2 $worker->wait()
-
-When in non-blocking I/O mode, wait for activity from one of the servers.
-
-=head2 $worker->set_log_fn($function, $verbose)
-
-Set logging function.
+Set options for a worker structure.
 
 =head1 BUGS
 
@@ -176,8 +108,7 @@ Any in libgearman plus many others of my own.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2013 Data Differential, ala Brian Aker, http://datadifferential.com/
-Copyright (C) 2009-2010 Dennis Schoen
+Copyright (C) 2009 Dennis Schoen
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.9 or,
@@ -187,13 +118,10 @@ at your option, any later version of Perl 5 you may have available.
 
 This is free software. IT COMES WITHOUT WARRANTY OF ANY KIND.
 
-=head1 LICENSE
+=head1 AUTHORS
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 AUTHOR
-
-Brian Aker <brian@tangent.org>
+Dennis Schoen <dennis@blogma.de>
 
 =cut
+
+1;
\ No newline at end of file
